@@ -1,12 +1,12 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2014
 #
-`extractAIC.mvmeta` <-
+extractAIC.mvmeta <-
 function (object, ...) {
 #
 ################################################################################
 # EXTRACTS THE NUMBER OF OBSERVATIONS USED FOR FITTING. USED BY BIC
 #
-   return(c(object$df$df,AIC(object)))
+   c(object$df$df,AIC(object))
 #
 }
\ No newline at end of file
